from setuptools import setup
setup(name="pkgF12",     # How you named your package folder (MyLib)
version="0.9",      # Start with a small number and increase it with every change you make
description="This Is pkgF1 desc",
long_description="This Is pkgF1 longggg desc",
license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
author="abc",
packages=['pkgF12'],
install_requires = [])



# setup(
#   name = 'YOURPACKAGENAME',         
#   packages = ['YOURPACKAGENAME'],   # Chose the same as "name"
#   version = '0.1',      # Start with a small number and increase it with every change you make
#   license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
#   description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
#   author = 'YOUR NAME',                   # Type in your name
#   author_email = 'your.email@domain.com',      # Type in your E-Mail
#   url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
#   download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
#   keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
#   install_requires=[            # I get to this in a second
#           'validators',
#           'beautifulsoup4',
#       ],
#   classifiers=[
#     'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
#     'Intended Audience :: Developers',      # Define that your audience are developers
#     'Topic :: Software Development :: Build Tools',
#     'License :: OSI Approved :: MIT License',   # Again, pick a license
#     'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
#     'Programming Language :: Python :: 3.4',
#     'Programming Language :: Python :: 3.5',
#     'Programming Language :: Python :: 3.6',
#   ],
# )